@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/Modules/AdminAttachment.pm - provides admin std response module
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: AdminAttachment.pm,v 1.40 2012-02-27 22:53:37 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminAttachment;
@@ -11,9 +14,11 @@ package Kernel::Modules::AdminAttachment;
 use strict;
 use warnings;
 
-use Kernel::Language qw(Translatable);
+use Kernel::System::StdAttachment;
+use Kernel::System::Valid;
 
-our $ObjectManagerDisabled = 1;
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.40 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -22,36 +27,39 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
+    # check all needed objects
+    for my $Needed (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
+        }
+    }
+    $Self->{StdAttachmentObject} = Kernel::System::StdAttachment->new(%Param);
+    $Self->{ValidObject}         = Kernel::System::Valid->new(%Param);
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject        = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $ParamObject         = $Kernel::OM->Get('Kernel::System::Web::Request');
-    my $StdAttachmentObject = $Kernel::OM->Get('Kernel::System::StdAttachment');
-
     # ------------------------------------------------------------ #
     # change
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Change' ) {
-        my $ID   = $ParamObject->GetParam( Param => 'ID' ) || '';
-        my %Data = $StdAttachmentObject->StdAttachmentGet(
-            ID => $ID,
-        );
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
+        my %Data = $Self->{StdAttachmentObject}->StdAttachmentGet( ID => $ID, );
 
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action => 'Change',
             %Data,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminAttachment',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -61,17 +69,18 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my @NewIDs = $ParamObject->GetArray( Param => 'IDs' );
+        my @NewIDs = $Self->{ParamObject}->GetArray( Param => 'IDs' );
         my ( %GetParam, %Errors );
         for my $Parameter (qw(ID Name Comment ValidID)) {
-            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
         # get attachment
-        my %UploadStuff = $ParamObject->GetUploadAll(
-            Param => 'FileUpload',
+        my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
+            Param  => 'FileUpload',
+            Source => 'string',
         );
 
         # check needed data
@@ -85,44 +94,39 @@ sub Run {
         if ( !%Errors ) {
 
             # update attachment
-            my $Update = $StdAttachmentObject->StdAttachmentUpdate(
+            my $Update = $Self->{StdAttachmentObject}->StdAttachmentUpdate(
                 %GetParam,
                 %UploadStuff,
                 UserID => $Self->{UserID},
             );
             if ($Update) {
-
-                # if the user would like to continue editing the attachment, just redirect to the edit screen
-                if (
-                    defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
-                    && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
-                    )
-                {
-                    my $ID = $ParamObject->GetParam( Param => 'ID' ) || '';
-                    return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Subaction=Change;ID=$ID" );
-                }
-                else {
-
-                    # otherwise return to overview
-                    return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
-                }
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Attachment updated!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminAttachment',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
             }
         }
 
         # something has gone wrong
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Priority => 'Error' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action => 'Change',
             Errors => \%Errors,
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminAttachment',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -131,18 +135,18 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam;
-        $GetParam{Name} = $ParamObject->GetParam( Param => 'Name' );
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
+        $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action => 'Add',
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminAttachment',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -152,17 +156,18 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my @NewIDs = $ParamObject->GetArray( Param => 'IDs' );
+        my @NewIDs = $Self->{ParamObject}->GetArray( Param => 'IDs' );
         my ( %GetParam, %Errors );
         for my $Parameter (qw(ID Name Comment ValidID)) {
-            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
         # get attachment
-        my %UploadStuff = $ParamObject->GetUploadAll(
-            Param => 'FileUpload',
+        my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
+            Param  => 'FileUpload',
+            Source => 'string',
         );
 
         # check needed data
@@ -179,39 +184,39 @@ sub Run {
         if ( !%Errors ) {
 
             # add state
-            my $StdAttachmentID = $StdAttachmentObject->StdAttachmentAdd(
+            my $StdAttachmentID = $Self->{StdAttachmentObject}->StdAttachmentAdd(
                 %GetParam,
                 %UploadStuff,
                 UserID => $Self->{UserID},
             );
             if ($StdAttachmentID) {
                 $Self->_Overview();
-                my $Output = $LayoutObject->Header();
-                $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Notify( Info => Translatable('Attachment added!') );
-                $Output .= $LayoutObject->Output(
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Attachment added!' );
+                $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AdminAttachment',
                     Data         => \%Param,
                 );
-                $Output .= $LayoutObject->Footer();
+                $Output .= $Self->{LayoutObject}->Footer();
                 return $Output;
             }
         }
 
         # something has gone wrong
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Priority => 'Error' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action => 'Add',
             Errors => \%Errors,
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminAttachment',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -221,19 +226,18 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Delete' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $ID     = $ParamObject->GetParam( Param => 'ID' );
-        my $Delete = $StdAttachmentObject->StdAttachmentDelete(
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
+
+        my $Delete = $Self->{StdAttachmentObject}->StdAttachmentDelete(
             ID => $ID,
         );
+        if ( !$Delete ) {
+            return $Self->{LayoutObject}->ErrorScreen();
+        }
 
-        return $LayoutObject->Attachment(
-            ContentType => 'text/html',
-            Content     => ($Delete) ? $ID : 0,
-            Type        => 'inline',
-            NoCache     => 1,
-        );
+        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
     }
 
     # ------------------------------------------------------------ #
@@ -242,18 +246,16 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Download' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
 
-        my %Data = $StdAttachmentObject->StdAttachmentGet(
-            ID => $ID,
-        );
+        my %Data = $Self->{StdAttachmentObject}->StdAttachmentGet( ID => $ID, );
         if ( !%Data ) {
-            return $LayoutObject->ErrorScreen();
+            return $Self->{LayoutObject}->ErrorScreen();
         }
 
-        return $LayoutObject->Attachment(
+        return $Self->{LayoutObject}->Attachment(
             %Data,
             Type => 'attachment',
         );
@@ -264,13 +266,13 @@ sub Run {
     # ------------------------------------------------------------
     else {
         $Self->_Overview();
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminAttachment',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -279,29 +281,27 @@ sub Run {
 sub _Edit {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionList',
     );
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionOverview',
     );
 
     # get valid list
-    my %ValidList        = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+    my %ValidList        = $Self->{ValidObject}->ValidList();
     my %ValidListReverse = reverse %ValidList;
 
-    $Param{ValidOption} = $LayoutObject->BuildSelection(
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => \%ValidList,
         Name       => 'ValidID',
         SelectedID => $Param{ValidID} || $ValidListReverse{valid},
-        Class      => 'Modernize Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
 
     # add class for validation
@@ -309,7 +309,7 @@ sub _Edit {
         $Param{ValidateContent} = "Validate_Required";
     }
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
         Data => {
             %Param,
@@ -317,33 +317,37 @@ sub _Edit {
         },
     );
 
+    # shows header
+    if ( $Param{Action} eq 'Change' ) {
+        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+        $Self->{LayoutObject}->Block( Name => 'ContenLabelEdit' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
+        $Self->{LayoutObject}->Block( Name => 'ContenLabelAdd' );
+    }
+
     return 1;
 }
 
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject        = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $StdAttachmentObject = $Kernel::OM->Get('Kernel::System::StdAttachment');
-
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionList',
     );
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionAdd',
     );
-    $LayoutObject->Block(
-        Name => 'Filter',
-    );
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'OverviewResult',
         Data => \%Param,
     );
-    my %List = $StdAttachmentObject->StdAttachmentList(
+    my %List = $Self->{StdAttachmentObject}->StdAttachmentList(
         UserID => 1,
         Valid  => 0,
     );
@@ -352,13 +356,18 @@ sub _Overview {
     if (%List) {
 
         # get valid list
-        my %ValidList = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+        my %ValidList = $Self->{ValidObject}->ValidList();
         for my $ID ( sort { $List{$a} cmp $List{$b} } keys %List ) {
-            my %Data = $StdAttachmentObject->StdAttachmentGet(
-                ID => $ID,
-            );
+            my %Data = $Self->{StdAttachmentObject}->StdAttachmentGet( ID => $ID, );
 
-            $LayoutObject->Block(
+            if ( $ValidList{ $Data{ValidID} } eq 'valid' ) {
+                $Data{Invalid} = '';
+            }
+            else {
+                $Data{Invalid} = 'Invalid';
+            }
+
+            $Self->{LayoutObject}->Block(
                 Name => 'OverviewResultRow',
                 Data => {
                     Valid => $ValidList{ $Data{ValidID} },
@@ -370,7 +379,7 @@ sub _Overview {
 
     # otherwise a no data message is displayed
     else {
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'NoDataFoundMsg',
             Data => {},
         );
