@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/Modules/AdminSalutation.pm - to add/update/delete system addresses
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: AdminSalutation.pm,v 1.52 2012-02-27 22:53:37 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminSalutation;
@@ -11,9 +14,12 @@ package Kernel::Modules::AdminSalutation;
 use strict;
 use warnings;
 
-use Kernel::Language qw(Translatable);
+use Kernel::System::Salutation;
+use Kernel::System::Valid;
+use Kernel::System::HTMLUtils;
 
-our $ObjectManagerDisabled = 1;
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.52 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -22,35 +28,39 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
+    # check all needed objects
+    for my $Needed (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
+        }
+    }
+    $Self->{SalutationObject} = Kernel::System::Salutation->new(%Param);
+    $Self->{ValidObject}      = Kernel::System::Valid->new(%Param);
+    $Self->{HTMLUtilsObject}  = Kernel::System::HTMLUtils->new(%Param);
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject      = $Kernel::OM->Get('Kernel::System::Web::Request');
-    my $LayoutObject     = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $SalutationObject = $Kernel::OM->Get('Kernel::System::Salutation');
-
     # ------------------------------------------------------------ #
     # change
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Change' ) {
-        my $ID   = $ParamObject->GetParam( Param => 'ID' ) || '';
-        my %Data = $SalutationObject->SalutationGet(
-            ID => $ID,
-        );
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
+        my %Data = $Self->{SalutationObject}->SalutationGet( ID => $ID, );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action => 'Change',
             %Data,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutation',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -60,26 +70,22 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         my $Note = '';
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Comment ValidID)) {
-            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+        for my $Parameter (qw(ID Name Text Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
-        $GetParam{'Text'} = $ParamObject->GetParam(
-            Param => 'Text',
-            Raw   => 1
-        ) || '';
 
         # get content type
         my $ContentType = 'text/plain';
-        if ( $LayoutObject->{BrowserRichText} ) {
+        if ( $Self->{LayoutObject}->{BrowserRichText} ) {
             $ContentType = 'text/html';
         }
 
         # check needed data
-        for my $Needed (qw(Name ValidID Text)) {
+        for my $Needed (qw(Name ValidID)) {
             if ( !$GetParam{$Needed} ) {
                 $Errors{ $Needed . 'Invalid' } = 'ServerError';
             }
@@ -89,44 +95,39 @@ sub Run {
         if ( !%Errors ) {
 
             # update salutation
-            my $Update = $SalutationObject->SalutationUpdate(
+            my $Update = $Self->{SalutationObject}->SalutationUpdate(
                 %GetParam,
                 ContentType => $ContentType,
                 UserID      => $Self->{UserID},
             );
             if ($Update) {
-
-                # if the user would like to continue editing the salutation, just redirect to the edit screen
-                if (
-                    defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
-                    && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
-                    )
-                {
-                    my $ID = $ParamObject->GetParam( Param => 'ID' ) || '';
-                    return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Subaction=Change;ID=$ID" );
-                }
-                else {
-
-                    # otherwise return to overview
-                    return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
-                }
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Updated!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminSalutation',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
             }
         }
 
         # something has gone wrong
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Priority => 'Error' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action => 'Change',
             Errors => \%Errors,
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutation',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -135,18 +136,18 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam = ();
-        $GetParam{Name} = $ParamObject->GetParam( Param => 'Name' );
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
+        $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action => 'Add',
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutation',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -156,26 +157,22 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         my $Note = '';
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Comment ValidID)) {
-            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+        for my $Parameter (qw(ID Name Text Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
-        $GetParam{'Text'} = $ParamObject->GetParam(
-            Param => 'Text',
-            Raw   => 1
-        ) || '';
 
         # get content type
         my $ContentType = 'text/plain';
-        if ( $LayoutObject->{BrowserRichText} ) {
+        if ( $Self->{LayoutObject}->{BrowserRichText} ) {
             $ContentType = 'text/html';
         }
 
         # check needed data
-        for my $Needed (qw(Name ValidID Text)) {
+        for my $Needed (qw(Name ValidID)) {
             if ( !$GetParam{$Needed} ) {
                 $Errors{ $Needed . 'Invalid' } = 'ServerError';
             }
@@ -185,7 +182,7 @@ sub Run {
         if ( !%Errors ) {
 
             # add salutation
-            my $AddressID = $SalutationObject->SalutationAdd(
+            my $AddressID = $Self->{SalutationObject}->SalutationAdd(
                 %GetParam,
                 ContentType => $ContentType,
                 UserID      => $Self->{UserID},
@@ -193,32 +190,32 @@ sub Run {
 
             if ($AddressID) {
                 $Self->_Overview();
-                my $Output = $LayoutObject->Header();
-                $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Notify( Info => Translatable('Salutation added!') );
-                $Output .= $LayoutObject->Output(
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Added!' );
+                $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AdminSalutation',
                     Data         => \%Param,
                 );
-                $Output .= $LayoutObject->Footer();
+                $Output .= $Self->{LayoutObject}->Footer();
                 return $Output;
             }
         }
 
         # something has gone wrong
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Priority => 'Error' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action => 'Add',
             Errors => \%Errors,
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutation',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -227,13 +224,13 @@ sub Run {
     # ------------------------------------------------------------
     else {
         $Self->_Overview();
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutation',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -242,20 +239,16 @@ sub Run {
 sub _Edit {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject    = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
-
     # add rich text editor
-    if ( $LayoutObject->{BrowserRichText} ) {
-
-        # set up rich text editor
-        $LayoutObject->SetRichTextParameters(
+    if ( $Self->{LayoutObject}->{BrowserRichText} ) {
+        $Self->{LayoutObject}->Block(
+            Name => 'RichText',
             Data => \%Param,
         );
 
         # reformat from plain to html
         if ( $Param{ContentType} && $Param{ContentType} =~ /text\/plain/i ) {
-            $Param{Text} = $HTMLUtilsObject->ToHTML(
+            $Param{Text} = $Self->{HTMLUtilsObject}->ToHTML(
                 String => $Param{Text},
             );
         }
@@ -264,36 +257,36 @@ sub _Edit {
 
         # reformat from html to plain
         if ( $Param{ContentType} && $Param{ContentType} =~ /text\/html/i ) {
-            $Param{Text} = $HTMLUtilsObject->ToAscii(
+            $Param{Text} = $Self->{HTMLUtilsObject}->ToAscii(
                 String => $Param{Text},
             );
         }
     }
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionList',
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionOverview',
     );
 
     # get valid list
-    my %ValidList        = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+    my %ValidList        = $Self->{ValidObject}->ValidList();
     my %ValidListReverse = reverse %ValidList;
 
-    $Param{ValidOption} = $LayoutObject->BuildSelection(
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => \%ValidList,
         Name       => 'ValidID',
         SelectedID => $Param{ValidID} || $ValidListReverse{valid},
-        Class      => 'Modernize Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
         Data => {
             %Param,
@@ -301,51 +294,47 @@ sub _Edit {
         },
     );
 
+    # shows header
+    if ( $Param{Action} eq 'Change' ) {
+        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
+    }
+
     return 1;
 }
 
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionList',
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ActionAdd',
     );
-
-    $LayoutObject->Block(
-        Name => 'Filter',
-    );
-
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'OverviewResult',
         Data => \%Param,
     );
-
-    my $SalutationObject = $Kernel::OM->Get('Kernel::System::Salutation');
-
-    my %List = $SalutationObject->SalutationList(
-        Valid => 0,
-    );
+    my %List = $Self->{SalutationObject}->SalutationList( Valid => 0, );
 
     # if there are any results, they are shown
     if (%List) {
 
         # get valid list
-        my %ValidList = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+        my %ValidList = $Self->{ValidObject}->ValidList();
         for my $ListKey ( sort { $List{$a} cmp $List{$b} } keys %List ) {
 
-            my %Data = $SalutationObject->SalutationGet( ID => $ListKey );
-            $LayoutObject->Block(
+            my %Data = $Self->{SalutationObject}->SalutationGet( ID => $ListKey );
+            $Self->{LayoutObject}->Block(
                 Name => 'OverviewResultRow',
                 Data => {
                     Valid => $ValidList{ $Data{ValidID} },
@@ -357,7 +346,7 @@ sub _Overview {
 
     # otherwise a no data message is displayed
     else {
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'NoDataFoundMsg',
             Data => {},
         );
