@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketEscalationView.pm - status for all open tickets
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketEscalationView.pm,v 1.15 2010-04-12 21:41:57 martin Exp $
+# $Id: AgentTicketEscalationView.pm,v 1.16.2.2 2012-08-17 09:15:51 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.15 $) [1];
+$VERSION = qw($Revision: 1.16.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -101,7 +101,7 @@ sub Run {
                 OrderBy                       => $Self->{OrderBy},
                 SortBy                        => $Self->{SortBy},
                 UserID                        => $Self->{UserID},
-                Permission                    => 'ro',
+                Permission                    => $Self->{Config}->{'TicketPermission'},
             },
         },
         Tomorrow => {
@@ -112,18 +112,18 @@ sub Run {
                 OrderBy                       => $Self->{OrderBy},
                 SortBy                        => $Self->{SortBy},
                 UserID                        => $Self->{UserID},
-                Permission                    => 'ro',
+                Permission                    => $Self->{Config}->{'TicketPermission'},
             },
         },
         NextWeek => {
-            Name   => 'Next Week',
+            Name   => 'Next week',
             Prio   => 3000,
             Search => {
                 TicketEscalationTimeOlderDate => $TimeStampNextWeek,
                 OrderBy                       => $Self->{OrderBy},
                 SortBy                        => $Self->{SortBy},
                 UserID                        => $Self->{UserID},
-                Permission                    => 'ro',
+                Permission                    => $Self->{Config}->{'TicketPermission'},
             },
         },
     );
