@@ -1,5 +1,8 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/ArticleAttachmentHTMLViewer.pm
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: ArticleAttachmentHTMLViewer.pm,v 1.11 2011-02-18 23:43:17 mp Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +14,9 @@ package Kernel::Output::HTML::ArticleAttachmentHTMLViewer;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.11 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -31,17 +37,14 @@ sub Run {
     # check needed stuff
     for (qw(File Article)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
     # check if config exists
     if ( $Self->{ConfigObject}->Get('MIME-Viewer') ) {
-        for ( sort keys %{ $Self->{ConfigObject}->Get('MIME-Viewer') } ) {
+        for ( keys %{ $Self->{ConfigObject}->Get('MIME-Viewer') } ) {
             if ( $Param{File}->{ContentType} =~ /^$_/i ) {
                 return (
                     %{ $Param{File} },
