@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/ArticleComposeCrypt.pm
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleComposeCrypt.pm,v 1.20.2.1 2012/05/24 23:19:30 cr Exp $
+# $Id: ArticleComposeCrypt.pm,v 1.21.2.1 2012-05-24 23:19:22 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Mail::Address;
 use Kernel::System::Crypt;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.20.2.1 $) [1];
+$VERSION = qw($Revision: 1.21.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -167,8 +167,8 @@ sub Data {
                 if ( $DataRef->{EndDate} ) {
                     $EndDate = "[$DataRef->{EndDate}]";
                 }
-                $KeyList{"SMIME::Detached::$DataRef->{Hash}"}
-                    = "SMIME-Detached: $DataRef->{Hash} $EndDate $DataRef->{Email}";
+                $KeyList{"SMIME::Detached::$DataRef->{Filename}"}
+                    = "SMIME-Detached: $DataRef->{Filename} $EndDate $DataRef->{Email}";
             }
         }
 
