@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/DashboardTicketStatsGeneric.pm
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: DashboardTicketStatsGeneric.pm,v 1.8 2009/07/13 23:23:53 martin Exp $
+# $Id: DashboardTicketStatsGeneric.pm,v 1.19 2011-11-24 10:22:50 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.8 $) [1];
+$VERSION = qw($Revision: 1.19 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -29,7 +29,7 @@ sub new {
         qw(Config Name ConfigObject LogObject DBObject LayoutObject ParamObject TicketObject UserID)
         )
     {
-        die "Got no $_!" if ( !$Self->{$_} );
+        die "Got no $_!" if !$Self->{$_};
     }
 
     return $Self;
@@ -57,23 +57,21 @@ sub Run {
 
     my %Axis = (
         '7Day' => {
-            0 => { Day => 'Sun', Created => 0, Closed => 0, },
-            1 => { Day => 'Mon', Created => 0, Closed => 0, },
-            2 => { Day => 'Tue', Created => 0, Closed => 0, },
-            3 => { Day => 'Wed', Created => 0, Closed => 0, },
-            4 => { Day => 'Thu', Created => 0, Closed => 0, },
-            5 => { Day => 'Fri', Created => 0, Closed => 0, },
-            6 => { Day => 'Sat', Created => 0, Closed => 0, },
+            0 => 'Sun',
+            1 => 'Mon',
+            2 => 'Tue',
+            3 => 'Wed',
+            4 => 'Thu',
+            5 => 'Fri',
+            6 => 'Sat',
         },
     );
 
-    my $TimeNow = $Self->{TimeObject}->SystemTime();
-    my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay ) = $Self->{TimeObject}->SystemTime2Date(
-        SystemTime => $TimeNow,
-    );
-
-    my @Data;
-    my $Max = 1;
+    my @TicketsCreated = ();
+    my @TicketsClosed  = ();
+    my @TicketWeekdays = ();
+    my @TicketYAxis    = ();
+    my $Max            = 0;
     for my $Key ( 0 .. 6 ) {
 
         my $TimeNow = $Self->{TimeObject}->SystemTime();
@@ -85,12 +83,16 @@ sub Run {
             SystemTime => $TimeNow,
             );
 
-        $Data[$Key]->{Day} = $Self->{LayoutObject}->{LanguageObject}->Get(
-            $Axis{'7Day'}->{$WeekDay}->{Day}
+        unshift(
+            @TicketWeekdays,
+            [ 6 - $Key, $Self->{LayoutObject}->{LanguageObject}->Get( $Axis{'7Day'}->{$WeekDay} ) ]
         );
 
         my $CountCreated = $Self->{TicketObject}->TicketSearch(
 
+            # cache search result 30 min
+            CacheTTL => 60 * 30,
+
             # tickets with create time after ... (ticket newer than this date) (optional)
             TicketCreateTimeNewerDate => "$Year-$Month-$Day 00:00:00",
 
@@ -99,16 +101,21 @@ sub Run {
 
             CustomerID => $Param{Data}->{UserCustomerID},
             Result     => 'COUNT',
+
+            # search with user permissions
             Permission => $Self->{Config}->{Permission} || 'ro',
-            UserID     => $Self->{UserID},
+            UserID => $Self->{UserID},
         );
-        $Data[$Key]->{Created} = $CountCreated;
-        if ( $CountCreated > $Max ) {
+        if ( $CountCreated && $CountCreated > $Max ) {
             $Max = $CountCreated;
         }
+        push @TicketsCreated, [ 6 - $Key, $CountCreated ];
 
         my $CountClosed = $Self->{TicketObject}->TicketSearch(
 
+            # cache search result 30 min
+            CacheTTL => 60 * 30,
+
             # tickets with create time after ... (ticket newer than this date) (optional)
             TicketCloseTimeNewerDate => "$Year-$Month-$Day 00:00:00",
 
@@ -117,28 +124,81 @@ sub Run {
 
             CustomerID => $Param{Data}->{UserCustomerID},
             Result     => 'COUNT',
-            Permission => 'ro',
-            UserID     => $Self->{UserID},
+
+            # search with user permissions
+            Permission => $Self->{Config}->{Permission} || 'ro',
+            UserID => $Self->{UserID},
         );
-        $Data[$Key]->{Closed} = $CountClosed;
-        if ( $CountClosed > $Max ) {
+        if ( $CountClosed && $CountClosed > $Max ) {
             $Max = $CountClosed;
         }
+        push @TicketsClosed, [ 6 - $Key, $CountClosed ];
     }
 
-    @Data = reverse @Data;
-    my $Source = $Self->{LayoutObject}->JSON(
-        Data => \@Data,
+    # calculate the maximum height and the tick steps of y axis
+    if ( $Max <= 10 ) {
+        for ( my $i = 0; $i <= 10; $i += 2 ) {
+            push @TicketYAxis, $i
+        }
+    }
+    elsif ( $Max <= 20 ) {
+        for ( my $i = 0; $i <= 20; $i += 4 ) {
+            push @TicketYAxis, $i
+        }
+    }
+    elsif ( $Max <= 100 ) {
+        for ( my $i = 0; $i <= ( ( ( $Max - $Max % 10 ) / 10 ) + 1 ) * 10; $i += 10 ) {
+            push @TicketYAxis, $i
+        }
+    }
+    elsif ( $Max <= 1000 ) {
+        for ( my $i = 0; $i <= ( ( ( $Max - $Max % 100 ) / 100 ) + 1 ) * 100; $i += 100 ) {
+            push @TicketYAxis, $i
+        }
+    }
+    else {
+        for ( my $i = 0; $i <= ( ( ( $Max - $Max % 1000 ) / 1000 ) + 1 ) * 1000; $i += 1000 ) {
+            push @TicketYAxis, $i
+        }
+    }
+    my $ClosedText  = $Self->{LayoutObject}->{LanguageObject}->Get('Closed');
+    my $CreatedText = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
+
+    my @ChartData = (
+        {
+            data  => \@TicketsClosed,
+            label => $ClosedText,
+            color => "#BF8A2F"
+        },
+        {
+            data  => \@TicketsCreated,
+            label => $CreatedText,
+            color => "#6F98DF"
+        }
+    );
+
+    my $ChartDataJSON = $Self->{LayoutObject}->JSONEncode(
+        Data => \@ChartData,
+    );
+
+    my $TicketWeekdaysJSON = $Self->{LayoutObject}->JSONEncode(
+        Data => \@TicketWeekdays,
+    );
+
+    my $TicketYAxisJSON = $Self->{LayoutObject}->JSONEncode(
+        Data => \@TicketYAxis,
     );
 
     my $Content = $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentDashboardTicketStats',
         Data         => {
             %{ $Self->{Config} },
-            Key    => int rand 99999,
-            Max    => $Max,
-            Source => $Source,
+            Key            => int rand 99999,
+            ChartData      => $ChartDataJSON,
+            TicketWeekdays => $TicketWeekdaysJSON,
+            TicketYAxis    => $TicketYAxisJSON
         },
+        KeepScriptTags => 1,
     );
 
     return $Content;
