@@ -1,5 +1,8 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Scheduler/TaskHandler/Test.pm - Scheduler task handler test backend
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: Test.pm,v 1.12 2011-07-26 19:50:13 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +16,9 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsHashRefWithData IsStringWithData);
 
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.12 $) [1];
+
 =head1 NAME
 
 Kernel::Scheduler::TaskHandler::Test - test backend of the TaskHandler for the Scheduler
@@ -54,7 +60,7 @@ performs the selected test task.
         Data     => {
             File              => $Filename,        # optional, create file $FileName
             Success           => 1,                # 0 or 1, controls return value
-            ReSchedule        => $ReSchedule,      # 0 or 1, controls re-scheduling
+            ReSchedule        => $ReSchedule,      # 0 or 1, constrols re-scheduling
             ReScheduleDueTime => $TimeStamp,
             ReScheduleData    => $Data,
         },
@@ -117,3 +123,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.12 $ $Date: 2011-07-26 19:50:13 $
+
+=cut
