@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Notification.pm - lib for notifications
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Notification.pm,v 1.36 2010/06/17 21:39:40 cr Exp $
+# $Id: Notification.pm,v 1.38.2.1 2012-06-07 11:51:01 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.36 $) [1];
+$VERSION = qw($Revision: 1.38.2.1 $) [1];
 
 =head1 NAME
 
@@ -112,48 +112,36 @@ sub NotificationGet {
         $Type     = $Self->{DBObject}->Quote($2);
     }
 
-    # db quote
-    $Param{ID} = $Self->{DBObject}->Quote( $Param{ID}, 'Integer' );
-
-    # sql
-    my $SQL = 'SELECT id, notification_type, notification_charset, '
-        . ' notification_language, subject, text, content_type '
-        . ' FROM notifications WHERE ';
-
-    if ( $Param{ID} ) {
-        $SQL .= " id = $Param{ID}";
-    }
-    else {
-        $SQL .= " notification_type = '$Type' AND notification_language = '$Language'";
-    }
-
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL );
+    $Self->{DBObject}->Prepare(
+        SQL => 'SELECT id, notification_type, notification_charset, '
+            . ' notification_language, subject, text, content_type '
+            . ' FROM notifications WHERE '
+            . ' notification_type = ? AND notification_language = ?',
+        Bind => [ \$Type, \$Language, ],
+        Limit => 1,
+    );
 
     my %Data;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
 
-        # convert to internal charset e. g. utf8
-        if ( $Self->{EncodeObject}->CharsetInternal() ) {
+        # convert body
+        $Data[5] = $Self->{EncodeObject}->Convert(
+            Text  => $Data[5],
+            From  => $Data[2],
+            To    => 'utf-8',
+            Force => 1,
+        );
 
-            # convert body
-            $Data[5] = $Self->{EncodeObject}->Convert(
-                Text  => $Data[5],
-                From  => $Data[2],
-                To    => $Self->{EncodeObject}->CharsetInternal(),
-                Force => 1,
-            );
+        # convert subject
+        $Data[3] = $Self->{EncodeObject}->Convert(
+            Text  => $Data[3],
+            From  => $Data[2],
+            To    => 'utf-8',
+            Force => 1,
+        );
 
-            # convert subject
-            $Data[3] = $Self->{EncodeObject}->Convert(
-                Text  => $Data[3],
-                From  => $Data[2],
-                To    => $Self->{EncodeObject}->CharsetInternal(),
-                Force => 1,
-            );
-
-            # set new charset
-            $Data[2] = $Self->{EncodeObject}->CharsetInternal();
-        }
+        # set new charset
+        $Data[2] = 'utf-8';
 
         # fix some bad stuff from some browsers (Opera)!
         $Data[5] =~ s/(\n\r|\r\r\n|\r\n|\r)/\n/g;
@@ -220,9 +208,6 @@ sub NotificationList {
     my %List;
     for my $Language ( keys %Languages ) {
 
-        # show only 'en' and not en_*
-        next if $Language =~ /^en_.+?$/;
-
         for my $Type ( keys %Types ) {
             $List{ $Language . '::' . $Type } = $Language . '::' . $Type;
         }
@@ -236,9 +221,6 @@ sub NotificationList {
 
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
 
-        # show only 'en' and not en_*
-        next if $Data[3] =~ /^en_.+?$/;
-
         # do not use customer notifications this way anymore (done by notification event now)
         next if $Data[1] =~ /Customer::(Owner|Queue|State)Update/;
 
@@ -317,6 +299,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.36 $ $Date: 2010/06/17 21:39:40 $
+$Revision: 1.38.2.1 $ $Date: 2012-06-07 11:51:01 $
 
 =cut
