@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/Ticket/Event/ForceUnlock.pm - unlock ticket
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: ForceUnlock.pm,v 1.11 2010-05-19 07:08:18 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Ticket::Event::ForceUnlock;
@@ -11,10 +14,8 @@ package Kernel::System::Ticket::Event::ForceUnlock;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::Log',
-    'Kernel::System::Ticket',
-);
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.11 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -23,6 +24,14 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # get needed objects
+    for (
+        qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject SendmailObject TimeObject EncodeObject)
+        )
+    {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
     return $Self;
 }
 
@@ -32,31 +41,24 @@ sub Run {
     # check needed stuff
     for (qw(Data Event Config)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
     for (qw(TicketID)) {
         if ( !$Param{Data}->{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_ in Data!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_ in Data!" );
             return;
         }
     }
 
     # unlock ticket
-    $Kernel::OM->Get('Kernel::System::Ticket')->TicketLockSet(
+    $Self->{TicketObject}->TicketLockSet(
         TicketID           => $Param{Data}->{TicketID},
         Lock               => 'unlock',
         SendNoNotification => 1,
         UserID             => 1,
     );
-
     return 1;
 }
 
