@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# otrs.RebuildEscalationIndex.pl - rebuild escalation index
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: otrs.RebuildEscalationIndex.pl,v 1.8 2010-11-25 08:48:06 bes Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,23 +12,25 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
 use warnings;
 
+# use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.8 $) [1];
 
 use Getopt::Std;
 
@@ -41,8 +46,8 @@ use Kernel::System::Ticket;
 my %Opts;
 getopt( 'h', \%Opts );
 if ( $Opts{h} ) {
-    print "otrs.RebuildEscalationIndex.pl - rebuild escalation index\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "otrs.RebuildEscalationIndex.pl <Revision $VERSION> - rebuild escalation index\n";
+    print "Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
     print "usage: otrs.RebuildEscalationIndex.pl\n";
     exit 1;
 }
@@ -81,7 +86,7 @@ for my $TicketID (@TicketIDs) {
         TicketID => $TicketID,
         UserID   => 1,
     );
-    if ( $Count % 2000 == 0 ) {
+    if ( ( $Count / 2000 ) == int( $Count / 2000 ) ) {
         my $Percent = int( $Count / ( $#TicketIDs / 100 ) );
         print "NOTICE: $Count of $#TicketIDs processed ($Percent% done).\n";
     }
