@@ -1,8 +1,8 @@
 // --
 // Core.Exception.js - provides the exception object and handling functions
-// Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.Exception.js,v 1.2 2010/10/04 08:47:24 mg Exp $
+// $Id: Core.Exception.js,v 1.7 2011-05-10 11:36:24 mg Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -20,6 +20,21 @@ var Core = Core || {};
  *      This namespace contains the functions for handling application errors.
  */
 Core.Exception = (function (TargetNS) {
+
+    /**
+     * @function Initialization code.
+     */
+    TargetNS.Init = function () {
+        /*
+         * Register an 'beforeunload' function which puts a status flag that
+         *  the current page is about to be left. Then AJAX errors because of
+         *  pending AJAX requests must be suppressed.
+         */
+        $(window).bind('beforeunload.Exception', function(){
+            // Use a public member so that we can also set it from a test case.
+            TargetNS.AboutToLeave = true;
+        });
+    };
     /**
      * @function
      *      This is the constructor for the application error object
@@ -72,23 +87,36 @@ Core.Exception = (function (TargetNS) {
      * @function
      *      This function handles the given error object (used as last possibility to catch the error)
      * @param {Object} Error The error object
-     * @return nothing
+     * @param {String} Trace (Optional) A string containing the stacktrace
+     * @return {Boolean} If the error could be handled, returns if it was shown to the user or not.
+     *      If the error could not be handled, this method will rethrow it.
      */
-    TargetNS.HandleFinalError = function (ErrorObject) {
-        var UserErrorMessage = 'An error occured! For details please see your browser log!';
+    TargetNS.HandleFinalError = function (ErrorObject, Trace) {
+        var UserErrorMessage = 'An error occurred! Do you want to see the complete error message?';
 
         if (ErrorObject instanceof TargetNS.ApplicationError) {
-            TargetNS.ShowError(ErrorObject.GetMessage(), ErrorObject.GetType());
-            window.alert(UserErrorMessage);
+            // Suppress AJAX errors which were raised by leaving the page while the AJAX call was still running.
+            if (TargetNS.AboutToLeave && ErrorObject.GetType() === 'CommunicationError') {
+                return false;
+            }
+            TargetNS.ShowError(ErrorObject.GetMessage(), ErrorObject.GetType(), Trace);
+            if (window.confirm(UserErrorMessage)) {
+                alert(ErrorObject.GetMessage() + (Trace ? ('\n\n' + Trace) : ''));
+            }
+            return true;
         }
         else if (ErrorObject instanceof Error) {
-            TargetNS.ShowError(ErrorObject.message, 'JavaScriptError');
-            window.alert(UserErrorMessage);
+            TargetNS.ShowError(ErrorObject.message, 'JavaScriptError', Trace);
+            if (window.confirm(UserErrorMessage)) {
+                alert(ErrorObject.message + (Trace ? ('\n\n' + Trace) : ''));
+            }
             throw ErrorObject; // rethrow
         }
         else {
-            TargetNS.ShowError(ErrorObject, 'UndefinedError');
-            window.alert(UserErrorMessage);
+            TargetNS.ShowError(ErrorObject, 'UndefinedError', Trace);
+            if (window.confirm(UserErrorMessage)) {
+                alert(ErrorObject + (Trace ? ('\n\n' + Trace) : ''));
+            }
             throw ErrorObject; // rethrow
         }
     };
@@ -98,11 +126,15 @@ Core.Exception = (function (TargetNS) {
      *      This function shows an error message in the log
      * @param {string} ErrorType The error type
      * @param {string} ErrorMessage The error message
+     * @param {string} Trace (Optional) The stacktrace
      * @return nothing
      */
-    TargetNS.ShowError = function (ErrorMessage, ErrorType) {
+    TargetNS.ShowError = function (ErrorMessage, ErrorType, Trace) {
         Core.Debug.Log('[ERROR] ' + ErrorType + ': ' + ErrorMessage);
+        if (typeof Trace !== 'undefined') {
+            Core.Debug.Log('[STACKTRACE] ' + Trace);
+        }
     };
 
     return TargetNS;
-}(Core.Exception || {}));
\ No newline at end of file
+}(Core.Exception || {}));
