@@ -1,8 +1,8 @@
 // --
 // Core.Form.Validate.js - provides functions for validating form inputs
-// Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.Form.Validate.js,v 1.24 2010/11/22 14:02:37 mn Exp $
+// $Id: Core.Form.Validate.js,v 1.34.2.6 2012-10-20 15:16:02 ep Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -52,6 +52,10 @@ Core.Form.Validate = (function (TargetNS) {
         return;
     }
 
+    if (!Core.Debug.CheckDependency('Core.Form.Validate', 'Core.Form.ErrorTooltips', 'Core.Form.ErrorTooltips')) {
+        return;
+    }
+
     /**
      * @function
      * @private
@@ -65,29 +69,38 @@ Core.Form.Validate = (function (TargetNS) {
             InputErrorMessageHTML,
             InputErrorMessageText;
 
-        /*
-         * Check error type and correct it, if necessary
-         */
+        // Check error type and correct it, if necessary
         if (ErrorType !== 'Error' && ErrorType !== 'ServerError') {
             ErrorType = 'Error';
         }
 
-        /*
-         * Add error class to field and its label
-         */
-        $Element.addClass(Options.ErrorClass);
-        $(Element.form).find("label[for=" + Element.id + "]").addClass(Options.ErrorLabelClass);
+        // Check if the element has already an error class
+        // (that means, this function call is an additional call)
+        if ($Element.hasClass(Options.ErrorClass)) {
+            return;
+        }
 
-        /*
-         * mark field as invalid for screenreader users
-         */
+        // Add error class to field and its label
+        $Element.addClass(Options.ErrorClass);
+        $(Element.form).find("label[for=" + Core.App.EscapeSelector(Element.id) + "]").addClass(Options.ErrorLabelClass);
+
+        // mark field as invalid for screenreader users
         $Element.attr('aria-invalid', true);
 
-        /* Get the target element and find the associated hidden div with the
-         * error message.
-         */
-        InputErrorMessageHTML = $('#' + $Element.attr('id') + ErrorType).html();
-        InputErrorMessageText = $('#' + $Element.attr('id') + ErrorType).text();
+        // save value of element for a later check if field value was changed.
+        // if the field has a servererror class and the value was not changed,
+        // keep the error class.
+        if ($Element.is('input:checkbox, input:radio')) {
+            $Element.data('ValidateOldValue', $Element.attr('checked'));
+        }
+        else {
+            $Element.data('ValidateOldValue', $Element.val());
+        }
+
+        // Get the target element and find the associated hidden div with the
+        // error message.
+        InputErrorMessageHTML = $(Core.App.EscapeSelector('#' + $Element.attr('id') + ErrorType)).html();
+        InputErrorMessageText = $(Core.App.EscapeSelector('#' + $Element.attr('id') + ErrorType)).text();
 
         if (InputErrorMessageHTML && InputErrorMessageHTML.length) {
             // if error field is a RTE, it is a little bit more difficult
@@ -98,10 +111,15 @@ Core.Form.Validate = (function (TargetNS) {
             }
         }
 
-        /*
-         * speak the error message for screen reader users
-         */
+        // speak the error message for screen reader users
         Core.UI.Accessibility.AudibleAlert(InputErrorMessageText);
+
+        // if the element, which has an validation error, is a richtext element, than manually trigger the focus event
+        if (Core.UI.RichTextEditor.IsEnabled($Element)) {
+            window.setTimeout(function () {
+                $Element.focus();
+            }, 0);
+        }
     }
 
     /**
@@ -112,24 +130,42 @@ Core.Form.Validate = (function (TargetNS) {
      * @description Remove error classes from element and its label
      */
     function UnHighlightError(Element) {
-        var $Element = $(Element);
+        var $Element = $(Element),
+            ElementValue,
+            RemoveError = true;
 
-        /*
-         * remove error classes from element and its label
-         */
-        $Element.removeClass(Options.ErrorClass);
-        $(Element.form).find("label[for=" + Element.id + "]").removeClass(Options.ErrorLabelClass);
+        // check ServerError
+        // if the field value has not changed, do not remove error class
+        if ($Element.hasClass(Options.ServerErrorClass)) {
+            if ($Element.is('input:checkbox, input:radio')) {
+                ElementValue = $Element.attr('checked');
+            }
+            else {
+                ElementValue = $Element.val();
+            }
 
-        /*
-         * mark field as valid for screenreader users
-         */
-        $Element.attr('aria-invalid', false);
+            if ($Element.data('ValidateOldValue') === ElementValue) {
+                RemoveError = false;
+            }
+            else {
+                $Element.removeData('ValidateOldValue');
+            }
+        }
 
-        // if error field is a RTE, it is a little bit more difficult
-        if ($('#cke_' + Element.id).length) {
-            Core.Form.ErrorTooltips.RemoveRTETooltip($Element);
-        } else {
-            Core.Form.ErrorTooltips.RemoveTooltip($Element);
+        if (RemoveError) {
+            // remove error classes from element and its label
+            $Element.removeClass(Options.ErrorClass).removeClass(Options.ServerErrorClass);
+            $(Element.form).find("label[for=" + Core.App.EscapeSelector(Element.id) + "]").removeClass(Options.ErrorLabelClass);
+
+            // mark field as valid for screenreader users
+            $Element.attr('aria-invalid', false);
+
+            // if error field is a RTE, it is a little bit more difficult
+            if ($('#cke_' + Element.id).length) {
+                Core.Form.ErrorTooltips.RemoveRTETooltip($Element);
+            } else {
+                Core.Form.ErrorTooltips.RemoveTooltip($Element);
+            }
         }
     }
 
@@ -159,7 +195,11 @@ Core.Form.Validate = (function (TargetNS) {
             Form.submit();
         }
         if ($(Form).hasClass("PreventMultipleSubmits")) {
-            Core.Form.DisableForm($(Form));
+            // fix for Safari: this "disable" comes to early after the submit, so that some fields are
+            // disabled before submitting and therefor are not submitted
+            window.setTimeout(function () {
+                Core.Form.DisableForm($(Form));
+            }, 0);
         }
     }
 
@@ -200,7 +240,22 @@ Core.Form.Validate = (function (TargetNS) {
      */
     $.validator.addMethod("Validate_Required", ValidatorMethodRequired, "");
     $.validator.addMethod("Validate_Number", $.validator.methods.digits, "");
-    $.validator.addMethod("Validate_Email", $.validator.methods.email, "");
+
+    // There is a configuration option in OTRS that controls if email addresses
+    // should be validated or not.
+    // If email address should be validated, this function is overwritten in Init method
+    $.validator.addMethod("Validate_Email", ValidatorMethodRequired, "");
+
+    // Use the maxlength attribute to have a dynamic validation
+    // Textarea fields will need JS code to set the maxlength attribute since is not supported by
+    // XHTML
+    $.validator.addMethod("Validate_MaxLength",function (Value, Element) {
+
+        // JS takes new lines '\n\r' in textarea elements as 1 character '\n' for length
+        // calculation purposes therefore is needed to re-add the '\r' to get the correct length
+        // for validation and match to perl and database criteria
+        return ( Value.replace(/\n\r?/g, "\n\r").length <= $(Element).attr('maxlength') );
+    }, "");
 
     $.validator.addMethod("Validate_DateYear", function (Value, Element) {
         return (parseInt(Value, 10) > 999 && parseInt(Value, 10) < 10000);
@@ -291,10 +346,9 @@ Core.Form.Validate = (function (TargetNS) {
             for (I = 0; I < EqualElements.length; I++) {
                 if ($('#' + $.trim(EqualElements[I])).val() === Value) {
                     ApplyRule++;
-                    break;
                 }
             }
-            return ApplyRule;
+            return (ApplyRule === EqualElements.length);
         }
     });
 
@@ -310,6 +364,10 @@ Core.Form.Validate = (function (TargetNS) {
         Validate_Email: true
     });
 
+    $.validator.addClassRules("Validate_MaxLength", {
+        Validate_MaxLength: true
+    });
+
     // Backwards compatibility: these methods are deprecated, do not use them!
     // They will be removed in OTRS 3.1.
     $.validator.addClassRules("Validate_RequiredDropdown", {
@@ -409,7 +467,7 @@ Core.Form.Validate = (function (TargetNS) {
 
 
     $.validator.addClassRules("Validate_DependingRequiredOR", {
-        Validate_DependingRequiredAND: true
+        Validate_DependingRequiredOR: true
     });
 
     /**
@@ -430,21 +488,34 @@ Core.Form.Validate = (function (TargetNS) {
         else {
             FormSelector = 'form';
         }
-        $(FormSelector).validate({
-            ignoreTitle: true,
-            errorClass: Options.ErrorClass,
-            highlight: HighlightError,
-            unhighlight: UnHighlightError,
-            errorPlacement: OnErrorElement,
-            submitHandler: OnSubmit,
-            ignore: '.' + Options.IgnoreClass
+
+        // There is a configuration option in OTRS that controls if email addresses
+        //  should be validated or not.
+        if (Core.Config.Get('CheckEmailAddresses')) {
+            $.validator.addMethod("Validate_Email", $.validator.methods.email, "");
+        }
+
+        // Init all forms separately, the validate plugin can
+        //  only handle one at a time.
+        $(FormSelector).each(function(){
+            $(this).validate({
+                ignoreTitle: true,
+                errorClass: Options.ErrorClass,
+                highlight: HighlightError,
+                unhighlight: UnHighlightError,
+                errorPlacement: OnErrorElement,
+                submitHandler: OnSubmit,
+                ignore: '.' + Options.IgnoreClass
+            });
         });
 
         /*
          * If on document load there are Error classes present, there were validation errors on server side.
          * Show an alert message and initialize the tooltips.
          */
-        $ServerErrors = $('input, textarea, select').filter('.' + Options.ServerErrorClass);
+        $ServerErrors = $('input.' + Options.ServerErrorClass)
+            .add('textarea.' + Options.ServerErrorClass)
+            .add('select.' + Options.ServerErrorClass);
 
         if ($ServerErrors.length) {
             $ServerErrors.each(function () {
